summaryrefslogtreecommitdiff
path: root/regnodes.h
diff options
context:
space:
mode:
authorYves Orton <demerphq@gmail.com>2022-04-18 09:57:51 +0200
committerYves Orton <demerphq@gmail.com>2022-08-03 11:07:09 +0200
commitf946e55ad047822276d1420651e4dc2d9caf3fce (patch)
treecbf22b8f36c0ef10a6ab2d28101712ac9b98ebb0 /regnodes.h
parentc0a7907be0f2bff18c64a6b2f3d09cb88c192dc3 (diff)
downloadperl-f946e55ad047822276d1420651e4dc2d9caf3fce.tar.gz
regen/regcomp.pl - Make regarglen available as PL_regarglen in regexec.c
In a follow up patch we will use this data from regexec.c which currently cannot see the variable. This changes a comment in regen/mk_invlists.pl which necessitated rebuilding several files related to unicode. Only the hashes associated with mk_invlists.pl were changed.
Diffstat (limited to 'regnodes.h')
-rw-r--r--regnodes.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/regnodes.h b/regnodes.h
index bf7cd9cf12..673dcf5643 100644
--- a/regnodes.h
+++ b/regnodes.h
@@ -1617,11 +1617,12 @@ EXTCONST U8 PL_regkind[] = {
};
#endif
-#ifdef REG_COMP_C
-
-/* regarglen[] - How large is the argument part of the node (in regnodes) */
+/* PL_regarglen[] - How large is the argument part of the node (in regnodes) */
-static const U8 regarglen[] = {
+#ifndef DOINIT
+EXTCONST U8 PL_regarglen[];
+#else
+EXTCONST U8 PL_regarglen[] = {
0, /* END */
0, /* SUCCEED */
0, /* SBOL */
@@ -1735,6 +1736,10 @@ static const U8 regarglen[] = {
0, /* PSEUDO */
EXTRA_SIZE(struct regnode_p), /* REGEX_SET */
};
+#endif /* DOINIT */
+
+
+#ifdef REG_COMP_C
/* reg_off_by_arg[] - Which argument holds the offset to the next node */